ALTER TABLE Discount ADD COLUMN isDeleted SMALLINT
CREATE INDEX Discount_isDeleted on Discount(isDeleted)

ALTER TABLE Message ADD COLUMN isDeleted SMALLINT
CREATE INDEX Message_isDeleted on Message(isDeleted)

ALTER TABLE Message_Person ADD COLUMN isDeleted SMALLINT
CREATE INDEX Message_Person_isDeleted on Message_Person(isDeleted)

ALTER TABLE MessageTemplate ADD COLUMN isDeleted SMALLINT
CREATE INDEX MessageTemplate_isDeleted on MessageTemplate(isDeleted)

ALTER TABLE WaitingList ADD COLUMN isDeleted SMALLINT
CREATE INDEX WaitingList_isDeleted on WaitingList(isDeleted)

ALTER TABLE WaitingList ADD COLUMN willowId SMALLINT
CREATE INDEX WaitingList_willowId on WaitingList(willowId)

DROP TABLE Certificate_Outcome
DROP TABLE Certificate

CREATE TABLE Certificate (certificateNumber BIGINT, createdOn TIMESTAMP, id BIGINT NOT NULL, isQualification SMALLINT, modifiedOn TIMESTAMP, printedOn TIMESTAMP, qualificationId BIGINT, studentId BIGINT, PRIMARY KEY (id))
CREATE TABLE Certificate_Outcome (certificateId BIGINT NOT NULL, createdOn TIMESTAMP, modifiedOn TIMESTAMP, outcomeId BIGINT NOT NULL, PRIMARY KEY (certificateId, outcomeId))

ALTER TABLE Certificate ADD FOREIGN KEY (qualificationId) REFERENCES Qualification (id)
ALTER TABLE Certificate ADD FOREIGN KEY (studentId) REFERENCES Student (id)
ALTER TABLE Certificate_Outcome ADD FOREIGN KEY (certificateId) REFERENCES Certificate (id)
ALTER TABLE Certificate_Outcome ADD FOREIGN KEY (outcomeId) REFERENCES Outcome (id)

CREATE INDEX Certificate_isQualification on Certificate(isQualification)
CREATE INDEX Certificate_printedOn on Certificate(printedOn)
CREATE INDEX Certificate_qualificationId on Certificate(qualificationId)
CREATE INDEX Certificate_studentId on Certificate(studentId)

INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('Certificate_Outcome', 200)


CREATE TABLE Node (createdOn TIMESTAMP, id INTEGER NOT NULL, isDeleted SMALLINT, isVocabulary SMALLINT, modifiedOn TIMESTAMP, name VARCHAR (512), nodeType SMALLINT, parentId INTEGER, shortName VARCHAR (128), contents VARCHAR (32000), willowId BIGINT, PRIMARY KEY (id))

CREATE TABLE NodeRequirement (createdOn TIMESTAMP, entityIdentifier SMALLINT, id INTEGER NOT NULL, isDeleted SMALLINT, isRequired SMALLINT, manyTermsAllowed SMALLINT, modifiedOn TIMESTAMP, nodeId INTEGER, willowId BIGINT, PRIMARY KEY (id))

CREATE TABLE NodeRelation (createdOn TIMESTAMP, entityIdentifier SMALLINT, entityRecordId INTEGER, id INTEGER NOT NULL, isDeleted SMALLINT, modifiedOn TIMESTAMP, nodeId INTEGER, tempEntityRecordId VARCHAR (256), willowId BIGINT, PRIMARY KEY (id))

ALTER TABLE Node ADD FOREIGN KEY (parentId) REFERENCES Node (id)
ALTER TABLE NodeRequirement ADD FOREIGN KEY (nodeId) REFERENCES Node (id)
ALTER TABLE NodeRelation ADD FOREIGN KEY (nodeId) REFERENCES Node (id)

CREATE INDEX Node_parentId on Node(parentId)
CREATE INDEX Node_willowId on Node(willowId)
CREATE INDEX Node_isDeleted on Node(isDeleted)
CREATE INDEX NodeRequirement_isDeleted on NodeRequirement(isDeleted)
CREATE INDEX NodeRequirement_entityIdentifier on NodeRequirement(entityIdentifier)
CREATE INDEX NodeRequirement_termId on NodeRequirement(nodeId)
CREATE INDEX NodeRequirement_isRequired on NodeRequirement(isRequired)
CREATE INDEX NodeRequirement_willowId on NodeRequirement(willowId)
CREATE INDEX NodeRelation_termId on NodeRelation(nodeId)
CREATE INDEX NodeRelation_entityIdentifier on NodeRelation(entityIdentifier)
CREATE INDEX NodeRelation_entityRecordId on NodeRelation(entityRecordId)
CREATE INDEX NodeRelation_isDeleted on NodeRelation(isDeleted)
CREATE INDEX NodeRelation_willowId on NodeRelation(willowId)

INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('NodeRelation', 200)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('NodeRequirement', 200)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('Node', 200)


CREATE TABLE BinaryInfo (byteSize BIGINT, createdOn TIMESTAMP, id INTEGER NOT NULL, isWebVisible SMALLINT, mimeType VARCHAR (512), isDeleted SMALLINT, modifiedOn TIMESTAMP, name VARCHAR (512), pixelHeight INTEGER, pixelWidth INTEGER, willowId BIGINT, PRIMARY KEY (id))

CREATE TABLE BinaryRelation (binaryInfoId INTEGER, createdOn TIMESTAMP, entityIdentifier VARCHAR (256), entityRecordId INTEGER, isDeleted SMALLINT, id INTEGER NOT NULL, modifiedOn TIMESTAMP, tempEntityRecordId VARCHAR (256), willowId BIGINT,  PRIMARY KEY (id))

CREATE TABLE BinaryData (binaryInfoId INTEGER NOT NULL, content BLOB NOT NULL, createdOn TIMESTAMP, id INTEGER NOT NULL, isDeleted SMALLINT, modifiedOn TIMESTAMP, willowId BIGINT , PRIMARY KEY (id))

ALTER TABLE BinaryRelation ADD FOREIGN KEY (binaryInfoId) REFERENCES BinaryInfo (id)
ALTER TABLE BinaryData ADD FOREIGN KEY (binaryInfoId) REFERENCES BinaryInfo (id)

CREATE INDEX BinaryInfo_mimeType on BinaryInfo(mimeType)
CREATE INDEX BinaryInfo_willowId on BinaryInfo(willowId)
CREATE INDEX BinaryInfo_isDeleted on BinaryInfo(isDeleted)
CREATE INDEX BinaryInfo_isWebVisible on BinaryInfo(isWebVisible)
CREATE INDEX BinaryRelation_isDeleted on BinaryRelation(isDeleted)
CREATE INDEX BinaryRelation_binaryInfoId on BinaryRelation(binaryInfoId)
CREATE INDEX BinaryRelation_entityIdentifier on BinaryRelation(entityIdentifier)
CREATE INDEX BinaryRelation_entityRecordId on BinaryRelation(entityRecordId)
CREATE INDEX BinaryRelation_willowId on BinaryRelation(willowId)
CREATE INDEX BinaryData_binaryInfoId on BinaryData(binaryInfoId)
CREATE INDEX BinaryData_isDeleted on BinaryData(isDeleted)
CREATE INDEX BinaryData_willowId on BinaryData(willowId)

INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('BinaryData', 200)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('BinaryInfo', 200)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('BinaryRelation', 200)



CREATE TABLE StudentDuplicate (createdOn TIMESTAMP, modifiedOn TIMESTAMP, id INTEGER NOT NULL, createdBy BIGINT, isFalsePositive SMALLINT NOT NULL, matchScore INTEGER, student1Id BIGINT NOT NULL, student2Id BIGINT NOT NULL, PRIMARY KEY (id))

ALTER TABLE StudentDuplicate ADD FOREIGN KEY (student1Id) REFERENCES Student (id)
ALTER TABLE StudentDuplicate ADD FOREIGN KEY (student2Id) REFERENCES Student (id)
ALTER TABLE StudentDuplicate ADD FOREIGN KEY (createdBy) REFERENCES SystemUser (id)

CREATE INDEX StudentDuplicate_student1Id on StudentDuplicate(student1Id)
CREATE INDEX StudentDuplicate_student2Id on StudentDuplicate(student2Id)
CREATE INDEX StudentDuplicate_matchScore on StudentDuplicate(matchScore)
CREATE INDEX StudentDuplicate_createdOn on StudentDuplicate(createdOn)


INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('StudentDuplicate', 200)

ALTER TABLE Tax ADD COLUMN taxrate DECIMAL (6, 4)
UPDATE Tax SET taxrate = rate
ALTER TABLE tax ALTER COLUMN rate NULL

update student SET student.isDeleted=0 WHERE student.ID IN (SELECT student.id FROM student JOIN Enrolment ON Enrolment.studentId = student.id where (enrolment.isdeleted is null or enrolment.isdeleted = 0))
update student SET student.isDeleted=0 WHERE student.ID IN (SELECT student.id FROM student JOIN Invoice ON Invoice.studentId = student.id)