# Refactoring for release 0.8
# Merge the student and tutor tables into contact

#############################
# migrate tutor ids
#############################
# this merge requires us to make tutor.id not collide with student.id
# but existing foreign key constraints make it impossible to just change the values

ALTER TABLE PaymentOut ADD COLUMN newTutorId BIGINT
ALTER TABLE Message_Person ADD COLUMN newTutorId BIGINT
ALTER TABLE CourseClass ADD COLUMN newTutorId BIGINT
ALTER TABLE Session ADD COLUMN newTutorId BIGINT

UPDATE PaymentOut SET newTutorId = tutorId + (SELECT MAX(id) FROM Student)
UPDATE Message_Person SET newTutorId = tutorId + (SELECT MAX(id) FROM Student)
UPDATE CourseClass SET newTutorId = tutorId + (SELECT MAX(id) FROM Student)
UPDATE Session SET newTutorId = tutorId + (SELECT MAX(id) FROM Student)

ALTER TABLE PaymentOut DROP tutorId 
ALTER TABLE Message_Person DROP tutorId 
ALTER TABLE CourseClass DROP tutorId 
ALTER TABLE Session DROP tutorId 

# now the constraints are gone the tutor table can be updated
UPDATE Tutor SET id = id + (SELECT MAX(id) FROM Student)
UPDATE NodeRelation SET entityRecordId = entityRecordId + (SELECT MAX(id) FROM Student) WHERE entityIdentifier = 4
UPDATE BinaryRelation SET entityRecordId = entityRecordId + (SELECT MAX(id) FROM Student) WHERE entityIdentifier = 'Tutor'
	
# now set back the relationships
ALTER TABLE PaymentOut ADD COLUMN tutorId BIGINT
ALTER TABLE Message_Person ADD COLUMN tutorId BIGINT
ALTER TABLE CourseClass ADD COLUMN tutorId BIGINT
ALTER TABLE Session ADD COLUMN tutorId BIGINT

UPDATE PaymentOut SET tutorId = newTutorId
UPDATE Message_Person SET tutorId = newTutorId
UPDATE CourseClass SET tutorId = newTutorId
UPDATE Session SET tutorId = newTutorId
	
ALTER TABLE PaymentOut ADD CONSTRAINT PaymentOut_tutor_fk FOREIGN KEY (tutorId) REFERENCES Tutor (id)
ALTER TABLE Message_Person ADD CONSTRAINT Message_Person_tutor_fk FOREIGN KEY (tutorId) REFERENCES Tutor (id)
ALTER TABLE CourseClass ADD CONSTRAINT CourseClass_tutor_fk FOREIGN KEY (tutorId) REFERENCES Tutor (id)
ALTER TABLE Session ADD CONSTRAINT Session_tutor_fk FOREIGN KEY (tutorId) REFERENCES Tutor (id)

# remove temp id column
ALTER TABLE PaymentOut DROP newTutorId 
ALTER TABLE Message_Person DROP newTutorId 
ALTER TABLE CourseClass DROP newTutorId 
ALTER TABLE Session DROP newTutorId

#############################

#move student attachments to contact
UPDATE BinaryRelation SET entityIdentifier='Contact' WHERE entityIdentifier = 'Student'
#move tutor attachments to contact
UPDATE BinaryRelation SET entityIdentifier='Contact' WHERE entityIdentifier = 'Tutor'


# create new contact table
CREATE TABLE Contact (abn VARCHAR (50), birthDate TIMESTAMP, countryId BIGINT, createdOn TIMESTAMP, email VARCHAR (500), fax VARCHAR (20), firstName VARCHAR (200), id BIGINT NOT NULL, isCompany SMALLINT, isDeleted SMALLINT, isMale SMALLINT, lastName VARCHAR (200), notes VARCHAR(32000), message VARCHAR (500), modifiedOn TIMESTAMP, homePhone VARCHAR (20), mobilePhone VARCHAR (20), workPhone VARCHAR (20), postcode VARCHAR (20), state VARCHAR (20), street VARCHAR (1000), studentId BIGINT, suburb VARCHAR (100), tfn VARCHAR (50), tutorId BIGINT,  webPassword VARCHAR(16), PRIMARY KEY (id))
CREATE TABLE ContactRelation (createdOn TIMESTAMP, fromContactId BIGINT, id BIGINT NOT NULL, modifiedOn TIMESTAMP, toContactId BIGINT,  typeId INTEGER, PRIMARY KEY (id))
CREATE TABLE ContactRelationType (id INTEGER, createdOn TIMESTAMP, modifiedOn TIMESTAMP, fromContactName VARCHAR(100), toContactName VARCHAR(100), PRIMARY KEY(id))

INSERT INTO ContactRelationType(id, createdOn, modifiedOn, fromContactName, toContactName) VALUES(1, CURRENT_TIMESTAMP, CURRENT_TIMESTAMP, 'Employer','Staff')
INSERT INTO ContactRelationType(id, createdOn, modifiedOn, fromContactName, toContactName) VALUES(2, CURRENT_TIMESTAMP, CURRENT_TIMESTAMP, 'Children','Parent')
INSERT INTO ContactRelationType(id, createdOn, modifiedOn, fromContactName, toContactName) VALUES(3, CURRENT_TIMESTAMP, CURRENT_TIMESTAMP, 'Sibling','Sibling')
INSERT INTO ContactRelationType(id, createdOn, modifiedOn, fromContactName, toContactName) VALUES(4, CURRENT_TIMESTAMP, CURRENT_TIMESTAMP, 'Spouse','Spouse')

INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('ContactRelationType', 200)

ALTER TABLE ContactRelation ADD CONSTRAINT Contact_Relation_Type_fk FOREIGN KEY (typeId) REFERENCES ContactRelationType (id)
ALTER TABLE Contact ADD CONSTRAINT Contact_country_fk FOREIGN KEY (countryId) REFERENCES Country (id)
ALTER TABLE Contact ADD CONSTRAINT Contact_student_fk FOREIGN KEY (studentId) REFERENCES Student (id)
ALTER TABLE Contact ADD CONSTRAINT Contact_tutor_fk FOREIGN KEY (tutorId) REFERENCES Tutor (id)
ALTER TABLE ContactRelation ADD CONSTRAINT ContactRelation_fromContact_fk FOREIGN KEY (fromContactId) REFERENCES Contact (id)
ALTER TABLE ContactRelation ADD CONSTRAINT ContactRelation_toContact_fk FOREIGN KEY (toContactId) REFERENCES Contact (id)

# now copy the data into new table
INSERT INTO Contact (id, studentId, birthdate, createdOn, email, fax, firstName, isDeleted, isMale, lastName, message, notes, postcode, state, street, suburb, webPassword) SELECT id, id,  birthdate, createdOn, email, fax, firstName, isDeleted, isMale, surname, message, notes, postcode, state, street, suburb, webPassword FROM Student

INSERT INTO Contact (id, tutorid, birthdate, createdOn, email, fax, firstName, isDeleted, isMale, lastName, notes,  postcode, state, street, suburb, tfn, webPassword) SELECT id, id,  birthdate, createdOn, email, fax, firstName, isDeleted, isMale, surname, notes, postcode, state, street, suburb, char(tfn), webPassword FROM Tutor

UPDATE Contact SET isCompany=0
CREATE INDEX Contact_email on Contact(email)
CREATE INDEX Contact_firstName on Contact(firstName)
CREATE INDEX Contact_isCompany on Contact(isCompany)
CREATE INDEX Contact_isDeleted on Contact(isDeleted)
CREATE INDEX Contact_isMale on Contact(isMale)
CREATE INDEX Contact_lastName on Contact(lastName)
CREATE INDEX Contact_postcode on Contact(postcode)
CREATE INDEX Contact_state on Contact(state)

# remove fields now moved into contact
ALTER TABLE Student DROP COLUMN birthdate
ALTER TABLE Student DROP COLUMN email
ALTER TABLE Student DROP COLUMN fax
ALTER TABLE Student DROP COLUMN firstName
ALTER TABLE Student DROP COLUMN isMale
ALTER TABLE Student DROP COLUMN surname
ALTER TABLE Student DROP COLUMN message
ALTER TABLE Student DROP COLUMN notes
ALTER TABLE Student DROP COLUMN postcode
ALTER TABLE Student DROP COLUMN state
ALTER TABLE Student DROP COLUMN street
ALTER TABLE Student DROP COLUMN suburb
ALTER TABLE Student DROP COLUMN webPassword

ALTER TABLE Tutor DROP COLUMN birthdate
ALTER TABLE Tutor DROP COLUMN email
ALTER TABLE Tutor DROP COLUMN fax
ALTER TABLE Tutor DROP COLUMN firstName
ALTER TABLE Tutor DROP COLUMN isMale
ALTER TABLE Tutor DROP COLUMN notes
ALTER TABLE Tutor DROP COLUMN surname
ALTER TABLE Tutor DROP COLUMN postcode
ALTER TABLE Tutor DROP COLUMN state
ALTER TABLE Tutor DROP COLUMN street
ALTER TABLE Tutor DROP COLUMN suburb
ALTER TABLE Tutor DROP COLUMN tfn
ALTER TABLE Tutor DROP COLUMN webPassword

# finalise the migration by setting the new pk for cayenne
INSERT INTO Contact (id) VALUES (1)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('Contact', (1 + (SELECT MAX(id) FROM CONTACT) ) )
DELETE FROM Contact WHERE id = 1

INSERT INTO Tutor (id) VALUES (1)
UPDATE AUTO_PK_SUPPORT SET NEXT_ID=(1 + (SELECT MAX(id) FROM TUTOR)) WHERE TABLE_NAME='Tutor'
DELETE FROM Tutor WHERE id = 1

# the main job is done, now fix all relationships
ALTER TABLE Message_Person ADD COLUMN contactId BIGINT
UPDATE Message_Person SET contactId = tutorId
ALTER TABLE Message_Person DROP COLUMN tutorId

ALTER TABLE Invoice ADD COLUMN contactId BIGINT
UPDATE Invoice SET contactId = studentId
ALTER TABLE Invoice DROP COLUMN studentId

ALTER TABLE PaymentIn ADD COLUMN payerId BIGINT
UPDATE PaymentIn SET payerId = studentId
ALTER TABLE PaymentIn DROP COLUMN studentId

ALTER TABLE PaymentOut ADD COLUMN payeeId BIGINT
UPDATE PaymentOut SET payeeId = tutorId where tutorId is not null
UPDATE PaymentOut SET payeeId = studentId where studentId is not null
ALTER TABLE PaymentOut DROP COLUMN tutorId
ALTER TABLE PaymentOut DROP COLUMN studentId

# StudentDuplicate can be dropped since it has no relevant data at this time
DROP TABLE StudentDuplicate

CREATE TABLE ContactDuplicate (contact1Id BIGINT NOT NULL, contact2Id BIGINT NOT NULL, createdBy BIGINT, createdOn TIMESTAMP, id BIGINT NOT NULL, isFalsePositive SMALLINT NOT NULL, matchScore INTEGER, modifiedOn TIMESTAMP, PRIMARY KEY (id))

ALTER TABLE ContactDuplicate ADD CONSTRAINT ContactDuplicate_systemuser_fk FOREIGN KEY (createdBy) REFERENCES SystemUser (id)
ALTER TABLE ContactDuplicate ADD CONSTRAINT ContactDuplicate_contact1_fk FOREIGN KEY (contact1Id) REFERENCES Contact (id)
ALTER TABLE ContactDuplicate ADD CONSTRAINT ContactDuplicate_contact2_fk FOREIGN KEY (contact2Id) REFERENCES Contact (id)

INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('ContactDuplicate', 200)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('ContactRelation', 200)
