# Indexe can speed up database operations, if they are set on frequently highly used columns. 
# Primary keys are automatically indexed.
# For small tables an index is disadvantageous, here for any function the system would be faster by scanning the whole table. 
# Do not use indexes on column where the value is often changed, because every time the index has also to be updated

# 1. All foreign key columns should be indexed because these columns are often used in join operations
# Derby and MySQL create automatically an index on a foreign key, if not already one exists on that column(s). NOT so MS SQL Server and Oracle
CREATE INDEX ACLAccessKey_roleId ON ACLAccessKey(role_Id)
CREATE INDEX ClassCost_courseClassId ON ClassCost(courseClassId)
CREATE INDEX ClassCost_createdbyUserId ON ClassCost(createdbyUserID)
CREATE INDEX ClassCost_taxId ON ClassCost(taxId)
CREATE INDEX Contact_countryId ON Contact(countryId)
CREATE INDEX ContactDuplicate_con1 ON ContactDuplicate(contact1Id)
CREATE INDEX ContactDuplicate_con2 ON ContactDuplicate(contact2Id)
CREATE INDEX ContactDuplicate_createdBy ON ContactDuplicate(createdBy)
CREATE INDEX ContactRelation_frcId ON ContactRelation(fromContactId)
CREATE INDEX ContactRelation_tocIf ON ContactRelation(toContactId)
CREATE INDEX ContactRelation_typeId ON ContactRelation(typeId)
CREATE INDEX CourseClass_incomeAccId ON CourseClass(incomeAccountId)
CREATE INDEX CourseClass_taxId ON CourseClass(taxId)
CREATE INDEX CourseClass_tutorId ON CourseClass(tutorId)
CREATE INDEX CourseSession_tutorId ON CourseSession(tutorId)
CREATE INDEX CustomField_foreignF ON CustomField(foreignId)
CREATE INDEX CustomField_cfTypeId ON CustomField(customFieldTypeId)
CREATE INDEX Invoice_contactId ON Invoice(contactId)
CREATE INDEX Message_createdByUserId ON Message(createdByUserId)
CREATE INDEX MessagePers_contacId ON Message_Person(contactId)
CREATE INDEX MessagePers_messageId ON Message_Person(messageId)
CREATE INDEX Module_trainPackId ON Module(trainingPackageId)
CREATE INDEX PaymentIn_payerId ON PaymentIn(payerId)
CREATE INDEX PaymentOut_payeeId ON PaymentOut(payeeId)
CREATE INDEX SavedFind_sysUserId ON SavedFind(systemUserId)
CREATE INDEX Student_contactId ON Student(contactId)
CREATE INDEX Tax_payableSuppAcc ON Tax(payableToSupplierAccountId)
CREATE INDEX Tax_receivStudAcc ON Tax(receivableFromStudentAccountId)
CREATE INDEX Tutor_contactId ON Tutor(contactId)


# 2. Add indexe for frequently used columns:

CREATE INDEX PaymentOutline_isDeleted on PaymentOutLine(isDeleted)

CREATE INDEX Contact_isStudent on Contact(isStudent)
CREATE INDEX Contact_isTutor on Contact(isTutor)

CREATE INDEX Country_willowId on Country(willowId)
CREATE INDEX CourseClassTutor_willowId on CourseClass_Tutor(willowId)
CREATE INDEX Invoice_willowId on Invoice(willowId)
CREATE INDEX InvoiceLine_willowId on InvoiceLine(willowId)
CREATE INDEX Language_willowId on Language(willowId)
CREATE INDEX Message_willowId on Message(willowId)
CREATE INDEX MessageTemplate_willowId on MessageTemplate(willowId)
CREATE INDEX MessagePerson_willowId on Message_Person(willowId)
CREATE INDEX PaymentIn_willowId on PaymentIn(willowId)
CREATE INDEX PaymentInLine_willowId on PaymentInLine(willowId)
CREATE INDEX PaymentOut_willowId on PaymentOut(willowId)
CREATE INDEX Preference_willowId on Preference(willowId)
CREATE INDEX SessionTutor_willowId on Session_Tutor(willowId)

CREATE INDEX Node_isVocabulary on Node(isVocabulary)
CREATE INDEX Node_isWebVisible on Node(isWebVisible)
CREATE INDEX Node_nodeType on Node(nodeType)

# 3. not to many indexe and not on columns which are not often used (would slow down the speed)
DROP INDEX Contact_postcode ON Contact
DROP INDEX Contact_state ON Contact
