ALTER TABLE Discount ADD COLUMN isDeleted SMALLINT
CREATE INDEX Discount_isDeleted on Discount(isDeleted)

ALTER TABLE Message ADD COLUMN isDeleted SMALLINT
CREATE INDEX Message_isDeleted on Message(isDeleted)

ALTER TABLE Message_Person ADD COLUMN isDeleted SMALLINT
CREATE INDEX Message_Person_isDeleted on Message_Person(isDeleted)

ALTER TABLE MessageTemplate ADD COLUMN isDeleted SMALLINT
CREATE INDEX MessageTemplate_isDeleted on MessageTemplate(isDeleted)

ALTER TABLE WaitingList ADD COLUMN isDeleted SMALLINT
CREATE INDEX WaitingList_isDeleted on WaitingList(isDeleted)

ALTER TABLE WaitingList ADD COLUMN willowId SMALLINT
CREATE INDEX WaitingList_willowId on WaitingList(willowId)

DROP TABLE Certificate_Outcome
DROP TABLE Certificate

CREATE TABLE Certificate (certificateNumber BIGINT, createdOn DATETIME, id BIGINT NOT NULL, isQualification SMALLINT, modifiedOn DATETIME, printedOn DATETIME, qualificationId BIGINT, studentId BIGINT, PRIMARY KEY (id))
CREATE TABLE Certificate_Outcome (certificateId BIGINT NOT NULL, createdOn DATETIME, modifiedOn DATETIME, outcomeId BIGINT NOT NULL, PRIMARY KEY (certificateId, outcomeId))

ALTER TABLE Certificate ADD CONSTRAINT fk_Cert_Qual FOREIGN KEY (qualificationId) REFERENCES Qualification (id)
ALTER TABLE Certificate ADD CONSTRAINT fk_Cert_Student FOREIGN KEY (studentId) REFERENCES Student (id)
ALTER TABLE Certificate_Outcome ADD CONSTRAINT fk_CertOut_Cert FOREIGN KEY (certificateId) REFERENCES Certificate (id)
ALTER TABLE Certificate_Outcome ADD CONSTRAINT fk_CertOut_Outcome FOREIGN KEY (outcomeId) REFERENCES Outcome (id)

CREATE INDEX Certificate_isQualification on Certificate(isQualification)
CREATE INDEX Certificate_printedOn on Certificate(printedOn)
CREATE INDEX Certificate_qualificationId on Certificate(qualificationId)
CREATE INDEX Certificate_studentId on Certificate(studentId)

INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('Certificate_Outcome', 200)


CREATE TABLE Node (createdOn DATETIME, id BIGINT NOT NULL, isDeleted SMALLINT, isVocabulary SMALLINT, modifiedOn DATETIME, name VARCHAR (512), nodeType SMALLINT, parentId BIGINT, shortName VARCHAR (128), contents TEXT (32000), willowId BIGINT, PRIMARY KEY (id))

CREATE TABLE NodeRequirement (createdOn DATETIME, entityIdentifier SMALLINT, id BIGINT NOT NULL, isDeleted SMALLINT, isRequired SMALLINT, manyTermsAllowed SMALLINT, modifiedOn DATETIME, nodeId BIGINT, willowId BIGINT, PRIMARY KEY (id))

CREATE TABLE NodeRelation (createdOn DATETIME, entityIdentifier SMALLINT, entityRecordId BIGINT, id BIGINT NOT NULL, isDeleted SMALLINT, modifiedOn DATETIME, nodeId BIGINT, tempEntityRecordId VARCHAR (256), willowId BIGINT, PRIMARY KEY (id))

ALTER TABLE Node ADD CONSTRAINT fk_Node_Node FOREIGN KEY (parentId) REFERENCES Node (id)
ALTER TABLE NodeRequirement ADD CONSTRAINT fk_NodeReq_Node FOREIGN KEY (nodeId) REFERENCES Node (id)
ALTER TABLE NodeRelation ADD CONSTRAINT fk_NodeRel_Node FOREIGN KEY (nodeId) REFERENCES Node (id)

CREATE INDEX Node_parentId on Node(parentId)
CREATE INDEX Node_willowId on Node(willowId)
CREATE INDEX Node_isDeleted on Node(isDeleted)
CREATE INDEX NodeRequirement_isDeleted on NodeRequirement(isDeleted)
CREATE INDEX NodeRequirement_entityIdentifier on NodeRequirement(entityIdentifier)
CREATE INDEX NodeRequirement_termId on NodeRequirement(nodeId)
CREATE INDEX NodeRequirement_isRequired on NodeRequirement(isRequired)
CREATE INDEX NodeRequirement_willowId on NodeRequirement(willowId)
CREATE INDEX NodeRelation_termId on NodeRelation(nodeId)
CREATE INDEX NodeRelation_entityIdentifier on NodeRelation(entityIdentifier)
CREATE INDEX NodeRelation_entityRecordId on NodeRelation(entityRecordId)
CREATE INDEX NodeRelation_isDeleted on NodeRelation(isDeleted)
CREATE INDEX NodeRelation_willowId on NodeRelation(willowId)

INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('NodeRelation', 200)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('NodeRequirement', 200)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('Node', 200)


CREATE TABLE BinaryInfo (byteSize BIGINT, createdOn DATETIME, id BIGINT NOT NULL, isWebVisible SMALLINT, mimeType VARCHAR (512), isDeleted SMALLINT, modifiedOn DATETIME, name VARCHAR (512), pixelHeight INTEGER, pixelWidth INTEGER, willowId BIGINT, PRIMARY KEY (id))

CREATE TABLE BinaryRelation (binaryInfoId BIGINT, createdOn DATETIME, entityIdentifier VARCHAR (256), entityRecordId BIGINT, isDeleted SMALLINT, id BIGINT NOT NULL, modifiedOn DATETIME, tempEntityRecordId VARCHAR (256), willowId BIGINT,  PRIMARY KEY (id))

CREATE TABLE BinaryData (binaryInfoId BIGINT NOT NULL, content BLOB NOT NULL, createdOn DATETIME, id BIGINT NOT NULL, isDeleted SMALLINT, modifiedOn DATETIME, willowId BIGINT , PRIMARY KEY (id))

ALTER TABLE BinaryRelation ADD CONSTRAINT fk_BinaryRel_BInfo FOREIGN KEY (binaryInfoId) REFERENCES BinaryInfo (id)
ALTER TABLE BinaryData ADD CONSTRAINT fk_BinaryData_BInfo FOREIGN KEY (binaryInfoId) REFERENCES BinaryInfo (id)

CREATE INDEX BinaryInfo_mimeType on BinaryInfo(mimeType)
CREATE INDEX BinaryInfo_willowId on BinaryInfo(willowId)
CREATE INDEX BinaryInfo_isDeleted on BinaryInfo(isDeleted)
CREATE INDEX BinaryInfo_isWebVisible on BinaryInfo(isWebVisible)
CREATE INDEX BinaryRelation_isDeleted on BinaryRelation(isDeleted)
CREATE INDEX BinaryRelation_binaryInfoId on BinaryRelation(binaryInfoId)
CREATE INDEX BinaryRelation_entityIdentifier on BinaryRelation(entityIdentifier)
CREATE INDEX BinaryRelation_entityRecordId on BinaryRelation(entityRecordId)
CREATE INDEX BinaryRelation_willowId on BinaryRelation(willowId)
CREATE INDEX BinaryData_binaryInfoId on BinaryData(binaryInfoId)
CREATE INDEX BinaryData_isDeleted on BinaryData(isDeleted)
CREATE INDEX BinaryData_willowId on BinaryData(willowId)

INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('BinaryData', 200)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('BinaryInfo', 200)
INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('BinaryRelation', 200)



CREATE TABLE StudentDuplicate (createdOn DATETIME, modifiedOn DATETIME, id INTEGER NOT NULL, createdBy BIGINT, isFalsePositive SMALLINT NOT NULL, matchScore INTEGER, student1Id BIGINT NOT NULL, student2Id BIGINT NOT NULL, PRIMARY KEY (id))

ALTER TABLE StudentDuplicate ADD CONSTRAINT fk_StudentDup_Stud1 FOREIGN KEY (student1Id) REFERENCES Student (id)
ALTER TABLE StudentDuplicate ADD CONSTRAINT fk_StudentDup_Stud2 FOREIGN KEY (student2Id) REFERENCES Student (id)
ALTER TABLE StudentDuplicate ADD CONSTRAINT fk_StudentDup_SystUser FOREIGN KEY (createdBy) REFERENCES SystemUser (id)

CREATE INDEX StudentDuplicate_student1Id on StudentDuplicate(student1Id)
CREATE INDEX StudentDuplicate_student2Id on StudentDuplicate(student2Id)
CREATE INDEX StudentDuplicate_matchScore on StudentDuplicate(matchScore)
CREATE INDEX StudentDuplicate_createdOn on StudentDuplicate(createdOn)


INSERT INTO AUTO_PK_SUPPORT (TABLE_NAME, NEXT_ID) VALUES ('StudentDuplicate', 200)

ALTER TABLE Tax ADD COLUMN taxrate DECIMAL (6, 4)
UPDATE Tax SET taxrate = rate
ALTER TABLE Tax MODIFY rate DECIMAL (6, 2) NULL
 

CREATE TABLE HELP (m BIGINT) SELECT Student.id FROM Student JOIN Enrolment ON Enrolment.studentId = Student.id where (Enrolment.isdeleted is null or Enrolment.isdeleted = 0)
update Student SET Student.isDeleted=0 WHERE Student.id IN (SELECT m FROM HELP)
DROP TABLE HELP

CREATE TABLE HELP2 (m BIGINT) SELECT Student.id FROM Student JOIN Invoice ON Invoice.studentId = Student.id
update Student SET Student.isDeleted=0 WHERE Student.id IN (SELECT m FROM HELP2)
DROP TABLE HELP2